@@ -28,8 +28,11 @@ setMethod(
   definition = function(x, f, margin = 1, negate = FALSE, na.rm = FALSE, ...) {
     assert_function(f)
     if (negate) f <- Negate(f)
-    x <- apply(X = x, MARGIN = margin, FUN = f, ...)
-    ## apply() returns an array of dimension c(n, dim(X)[MARGIN])
+    x <- apply(X = x, MARGIN = margin, FUN = f, ..., simplify = TRUE)
+    ## If simplify is TRUE:
+    ## apply() returns an array of dimension c(n, dim(X)[MARGIN]) if n > 1
+    ## apply() returns a vector if n == 1 and MARGIN has length 1
+    if (is.null(dim(x))) x <- matrix(x, nrow = 1)
     colSums(x, na.rm = na.rm)
   }
 )
